@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '0.93';
+$VERSION = '0.94';
 
 use base 'Exporter';
 
@@ -256,7 +256,7 @@ sub try(&@)
     if(   $err
        && !$disp->wasFatal
        && !UNIVERSAL::isa($err, 'Log::Report::Exception'))
-    {   eval "require Log::Report::Die";
+    {   eval "require Log::Report::Die"; panic $@ if $@;
         ($err, my($opts, $reason, $text)) = Log::Report::Die::die_decode($err);
         $disp->log($opts, $reason, __$text);
     }
